@@ -4,7 +4,8 @@ use warnings;
 
 package ToolSet;
 # ABSTRACT: Load your commonly-used modules in a single import
-our $VERSION = '1.01'; # VERSION
+
+our $VERSION = '1.02';
 
 use Carp;
 
@@ -62,6 +63,10 @@ sub import {
             my $args = join( q{ } => @$request );
             $evaltext = "package $caller; use $mod qw( $args )";
         }
+        elsif ( ref $request eq 'SCALAR' ) {
+            my $args = $$request;
+            $evaltext = "package $caller; use $mod $args";
+        }
         elsif ( ref( \$request ) eq 'SCALAR' ) {
             $evaltext = "package $caller; use $mod qw( $request )";
         }
@@ -131,170 +136,172 @@ ToolSet - Load your commonly-used modules in a single import
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 SYNOPSIS
 
 Creating a ToolSet:
 
-     # My/Tools.pm
-     package My::Tools;
- 
-     use base 'ToolSet'; 
- 
-     ToolSet->use_pragma( 'strict' );
-     ToolSet->use_pragma( 'warnings' );
-     ToolSet->use_pragma( qw/feature say switch/ ); # perl 5.10
- 
-     # define exports from other modules
-     ToolSet->export(
-         'Carp'          => undef,       # get the defaults
-         'Scalar::Util'  => 'refaddr',   # or a specific list
-     );
- 
-     # define exports from this module
-     our @EXPORT = qw( shout );
-     sub shout { print uc shift };
- 
-     1; # modules must return true
+    # My/Tools.pm
+    package My::Tools;
+
+    use base 'ToolSet';
+
+    ToolSet->use_pragma( 'strict' );
+    ToolSet->use_pragma( 'warnings' );
+    ToolSet->use_pragma( qw/feature say switch/ ); # perl 5.10
+
+    # define exports from other modules
+    ToolSet->export(
+        'Carp'          => undef,       # get the defaults
+        'Scalar::Util'  => 'refaddr',   # or a specific list
+    );
+
+    # define exports from this module
+    our @EXPORT = qw( shout );
+    sub shout { print uc shift };
+
+    1; # modules must return true
 
 Using a ToolSet:
 
-     # my_script.pl
- 
-     use My::Tools;
- 
-     # strict is on
-     # warnings are on
-     # Carp and refaddr are imported
- 
-     carp "We can carp!";
-     print refaddr [];
-     shout "We can shout, too!";
+    # my_script.pl
+
+    use My::Tools;
+
+    # strict is on
+    # warnings are on
+    # Carp and refaddr are imported
+
+    carp "We can carp!";
+    print refaddr [];
+    shout "We can shout, too!";
 
 =head1 DESCRIPTION
 
 ToolSet provides a mechanism for creating logical bundles of modules that can
 be treated as a single, reusable toolset that is imported as one.  Unlike
 CPAN bundles, which specify modules to be installed together, a toolset
-specifies modules to be imported together into other code.  
+specifies modules to be imported together into other code.
 
-ToolSet is designed to be a superclass -- subclasses will specify specific
+Toolset is designed to be a superclass -- subclasses will specify specific
 modules to bundle.  ToolSet supports custom import lists for each included
-module and even supports compile-time pragmas like C<<< strict >>>, C<<< warnings >>>
-and C<<< feature >>>. 
+module and even supports compile-time pragmas like C<strict>, C<warnings>
+and C<feature>.
 
-A ToolSet module does not physically bundle the component modules, but rather
-specifies lists of modules to be used together and import specifications for
-each.  By adding the component modules to a prerequisites list in a
-C<<< Makefile.PL >>> or C<<< Build.PL >>> for a ToolSet subclass, an entire dependency chain
-can be managed as a single unit across scripts or distributions that use the
-subclass.
+A ToolSet module does not physically bundle the component modules, but
+rather specifies lists of modules to be used together and import
+specifications for each.  By adding the component modules to a
+prerequisites list in a C<Makefile.PL> or C<Build.PL> for a ToolSet
+subclass, an entire dependency chain can be managed as a single unit across
+scripts or distributions that use the subclass.
 
-=head1 INTERFACE 
+=head1 INTERFACE
 
 =head2 Setting up
 
-     use base 'ToolSet';
+    use base 'ToolSet';
 
 ToolSet must be used as a base class.
 
-=head2 C<<< @EXPORT >>>
+=head2 C<@EXPORT>
 
-     our @EXPORT = qw( shout };
-     sub shout { print uc shift }
+    our @EXPORT = qw( shout };
+    sub shout { print uc shift }
 
 Functions defined in the ToolSet subclass can be automatically exported during
-C<<< use() >>> by listing them in an C<<< @EXPORT >>> array.
+C<use()> by listing them in an C<@EXPORT> array.
 
-=head2 C<<< export >>>
+=head2 C<export>
 
-     ToolSet->export(
-         'Carp' => undef,                    
-         'Scalar::Util' => 'refaddr',
-     );
+    ToolSet->export(
+        'Carp' => undef,
+        'Scalar::Util' => 'refaddr',
+    );
 
-Specifies packages and arguments to import via C<<< use() >>>.  An argument of C<<< undef >>>
-or the empty string calls C<<< use() >>> with default imports.  Arguments should be
+Specifies packages and arguments to import via C<use()>.  An argument of C<undef>
+or the empty string calls C<use()> with default imports.  Arguments should be
 provided either as a whitespace delimited string or in an anonymous array.  An
 empty anonymous array will be treated like passing the empty list as an
-argument to C<<< use() >>>.  Here are examples of how how specifications will be
-provided to C<<< use() >>>:
+argument to C<use()>.  Here are examples of how how specifications will be
+provided to C<use()>:
 
-     'Carp' => undef                 # use Carp; 
-     'Carp' => q{}                   # use Carp;
-     'Carp' => 'carp croak'          # use Carp qw( carp croak );
-     'Carp' => [ '!carp', 'croak' ]  # use Carp qw( !carp croak );
-     'Carp' => []                    # use Carp (); 
+    'Carp' => undef                 # use Carp;
+    'Carp' => q{}                   # use Carp;
+    'Carp' => 'carp croak'          # use Carp qw( carp croak );
+    'Carp' => [ '!carp', 'croak' ]  # use Carp qw( !carp croak );
+    'Carp' => []                    # use Carp ();
 
-Elements in an array are passed to C<<< use() >>> as a white-space separated list, so
-elements may not themselves contain spaces or unexpected results will occur.
+Elements in an array are passed to C<use()> as a white-space separated
+list, so elements may not themselves contain spaces or unexpected results
+will occur.  (But read further below about exact whitespace handling.)
 
 As of version 1.00, modules may be repeated multiple times.  This is useful
 with modules like L<autouse>.
 
-     ToolSet->export(
-       autouse => [ 'Carp' => qw(carp croak) ],
-       autouse => [ 'Scalar::Util' => qw(refaddr blessed) ],
-     );
+    ToolSet->export(
+      autouse => [ 'Carp' => qw(carp croak) ],
+      autouse => [ 'Scalar::Util' => qw(refaddr blessed) ],
+    );
 
-=head2 C<<< use_pragma >>>
+As of version 1.02, if you need exact handling of whitespace, pass a
+reference to a string and it will be used verbatim:
 
-   ToolSet->use_pragma( 'strict' );         # use strict;
-   ToolSet->use_pragma( 'feature', ':5.10' ); # use feature ':5.10';
+    'Foo' => \'-foo => { bar => "Some thing with spaces" }'
+
+    #  use Foo -foo => { bar => "Some thing with spaces" }'
+
+=head2 C<use_pragma>
+
+  ToolSet->use_pragma( 'strict' );         # use strict;
+  ToolSet->use_pragma( 'feature', ':5.10' ); # use feature ':5.10';
 
 Specifies a compile-time pragma to enable and optional arguments to that
-pragma.  This must only be used with pragmas that act via the magic C<<< $^H >>> or
-C<<< %^H >>> variables.  It must not be used with modules that have other side-effects
+pragma.  This must only be used with pragmas that act via the magic C<$^H> or
+C<%^H> variables.  It must not be used with modules that have other side-effects
 during import() such as exporting functions.
 
-=head2 C<<< no_pragma >>>
+=head2 C<no_pragma>
 
-   ToolSet->no_pragma( 'indirect' ); # no indirect;
+  ToolSet->no_pragma( 'indirect' ); # no indirect;
 
-Like C<<< use_pragma >>>, but disables a pragma instead.
+Like C<use_pragma>, but disables a pragma instead.
 
-If a pragma is specified in both a C<<< use_pragma >>> and C<<< no_pragma >>> statement, the
-C<<< use_pragma >>> will be executed first.  This allow turning on a pragma with 
+If a pragma is specified in both a C<use_pragma> and C<no_pragma> statement, the
+C<use_pragma> will be executed first.  This allow turning on a pragma with
 default settings and then disabling some of them.
 
-   ToolSet->use_pragma( 'strict' );
-   ToolSet->no_pragma ( 'strict', 'refs' ); 
+  ToolSet->use_pragma( 'strict' );
+  ToolSet->no_pragma ( 'strict', 'refs' );
 
-=head2 C<<< set_feature >>> (DEPRECATED)
+=head2 C<set_feature> (DEPRECATED)
 
-See C<<< use_pragma >>> instead.
+See C<use_pragma> instead.
 
-=head2 C<<< set_strict >>> (DEPRECATED)
+=head2 C<set_strict> (DEPRECATED)
 
-See C<<< use_pragma >>> instead.
+See C<use_pragma> instead.
 
-=head2 C<<< set_warnings >>> (DEPRECATED)
+=head2 C<set_warnings> (DEPRECATED)
 
-See C<<< use_pragma >>> instead.
+See C<use_pragma> instead.
 
 =head1 DIAGNOSTICS
 
 ToolSet will report an error for a module that cannot be found just like an
-ordinary call to C<<< use() >>> or C<<< require() >>>.
+ordinary call to C<use()> or C<require()>.
 
 Additional error messages include:
 
-=over
+=over 4
 
 =item *
 
-C<<< "Invalid import specification for MODULE" >>> -- an incorrect type was
-provided for the list to be imported (e.g. a hash reference)
-
-=back
-
-=over
+C<"Invalid import specification for MODULE"> -- an incorrect type was provided for the list to be imported (e.g. a hash reference)
 
 =item *
 
-C<<< "Can't import missing subroutine NAME" >>> -- the named subroutine is listed in
-C<<< @EXPORT >>>, but is not defined in the ToolSet subclass
+C<"Can't import missing subroutine NAME"> -- the named subroutine is listed in C<@EXPORT>, but is not defined in the ToolSet subclass
 
 =back
 
@@ -309,9 +316,9 @@ dependent on any modules they load.
 
 =head1 SEE ALSO
 
-Similar functionality is provided by the L<Toolkit> module, though that 
+Similar functionality is provided by the L<Toolkit> module, though that
 module requires defining the bundle via text files found within directories
-in C<<< PERL5LIB >>> and uses source filtering to insert their contents as files
+in C<PERL5LIB> and uses source filtering to insert their contents as files
 are compiled.
 
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
@@ -337,9 +344,15 @@ L<https://github.com/dagolden/ToolSet>
 
 David Golden <dagolden@cpan.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Haakon Haegland
+
+Haakon Haegland <Hakon.Hagland@uni.no>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by David Golden.
+This software is Copyright (c) 2016 by David Golden.
 
 This is free software, licensed under:
 
