@@ -5,9 +5,8 @@ use t::ToolSet::UseFeature;
 my $foo;
 my $bar;
 
-given ($foo) {
-    when (1) { $bar = "hello world" }
-    default  { $bar = "goodbye world" }
+sub hello {
+    say "hello";
 }
 
 1; # return true
