@@ -1,6 +1,6 @@
 package t::ToolSet::ExportBadType;
 use base 'ToolSet';
 
-ToolSet->export( 'Carp' => {}, );
+ToolSet->export( 'Carp' => sub { 1 }, );
 
 1; # return true
