@@ -1,8 +1,6 @@
 package t::ToolSet::ExportFails;
 use base 'ToolSet';
 
-ToolSet->export(
-    'Bogus::Module' => undef,
-);
+ToolSet->export( 'Bogus::Module' => undef, );
 
 1; # return true
