@@ -8,11 +8,11 @@ use base 'Exporter';
 our @EXPORT = qw( cant_ok );
 
 sub cant_ok ($@) {
-    my($proto, @methods) = @_;
+    my ( $proto, @methods ) = @_;
     my $class = ref $proto || $proto;
     my $tb = Test::More->builder;
 
-    unless( @methods ) {
+    unless (@methods) {
         my $ok = $tb->ok( 0, "$class->can(...)" );
         $tb->diag('    cant_ok() called with no methods');
         return $ok;
@@ -20,18 +20,20 @@ sub cant_ok ($@) {
 
     my @ok = ();
     foreach my $method (@methods) {
-        local($!, $@);  # don't interfere with caller's $@
+        local ( $!, $@ ); # don't interfere with caller's $@
         # eval sometimes resets $!
         eval { $proto->can($method) } && push @ok, $method;
     }
 
     my $name;
-    $name = @methods == 1 ? "$class->cant('$methods[0]')"
-    : "$class->cant(...)";
+    $name =
+      @methods == 1
+      ? "$class->cant('$methods[0]')"
+      : "$class->cant(...)";
 
     my $ok = $tb->ok( !@ok, $name );
 
-    $tb->diag(map "    $class->cant('$_') failed\n", @ok);
+    $tb->diag( map "    $class->cant('$_') failed\n", @ok );
 
     return $ok;
 }
